/*
	AEFlame - After Effects version of flame
	Original version of flame by Scott Draves <spot@cs.cmu.edu>
	After Effects version by Andrew B. Davidson <aeflame@mindspring.com> 
    flame Copyright (C) 1992 Scott Draves.  
    AEFlame Copyright (C) 1999 Andrew B. Davidson.  

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "PICA\SPFiles.h"
#include "AE_Macros.h"
#include <windows.h>




//=========================================================================
// returns the number of files in dir, and returns in oPath the iFileIndex'th
// file full path name.  Or, pass -1 for iFileIndex and NULL for oPath if 
// you just want the number of files.  iMatchPattern is a pattern to match
// like "*.MAP". You can only specify one pattern. Pass "*.*" if you want all files.
//-------------------------------------------------------------------------
//
// Win32 version
//
int GetNthFile(const char *iDirName, const char *iMatchPattern, long iFileIndex, char *oPath)
{
	long fileIndex = iFileIndex;
	BOOL success;
	DWORD error;
	HANDLE searchHandle;
	WIN32_FIND_DATA findFileData;
	long numFiles = 0;

	char wildcardDir[MAX_PATH];
	strcpy(wildcardDir, iDirName);
	strcat(wildcardDir, iMatchPattern);

 	searchHandle = FindFirstFile(wildcardDir, &findFileData);
	if (searchHandle == INVALID_HANDLE_VALUE)
	{
		// something is wrong
		error = GetLastError();
	}
	else
	{
		int finished = FALSE;
		if ((numFiles == fileIndex) && (!(findFileData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)))			// found the first file already above
		{
			// the file we want is in findFileData
			if (oPath != NULL)
			{
				strcpy(oPath, iDirName);
				strcat(oPath, findFileData.cFileName); 
			}
		}
		else
		{
			do
			{
				success = FindNextFile(searchHandle, &findFileData);
				if (!success)
				{
					error = GetLastError();
					if (error == ERROR_NO_MORE_FILES)
					{
						// no more files in this directory
						finished = TRUE;
					}
				}
				else
				{

					if (!(findFileData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY))
					{	
						if (numFiles == fileIndex)
						{
							if (oPath != NULL)
							{
								// the file we want is in findFileData
								strcpy(oPath, iDirName);
								strcat(oPath, findFileData.cFileName); 
							}
						}

						numFiles++;
					}
				}
			}
			while (!finished);
		}
 		
		success = FindClose(searchHandle);
		searchHandle = NULL;
		if (!success)
		{
			// something screwed up.
			error = GetLastError();
		}
	}
	return numFiles;
}



//=================================================================
// convert a full path into just the filename
// e.g. D:\dum\weird\stuff\test.txt becomes test.txt
// if called on a directory, it returns the last directory component
// e.g. D:\dum\weird\stuff\ becomes stuff\
// assumes dir sep char is '\'  ('\\' C-string escaped)
//-----------------------------------------------------------------
//
// Win32 version
//
void RemoveFullPath(char *ioString)
{
	long i;
	char *newStrPtr = NULL;
	long len = strlen(ioString);
	int found = FALSE;

	// skip dir char if necessary
	if (ioString[len-1] == '\\')
		len--;

	for ( i = len-1 ; (i>=0) && (!found) ; i-- )
	{
		if (ioString[i] == '\\')
		{
			found = TRUE;
			newStrPtr = &(ioString[i+1]);
		}
	}

	if (newStrPtr != NULL)
	{
		memmove(ioString, newStrPtr, (len - i) + 1);
	}
}
